﻿(function ($) {
	$.fn.testTimer = function (options) {
		let settings = $.extend(true, {
			startTime: null,
			endTime: null,
			text: "Осталось",
			tick: 1000,

			onEndedTime: undefined,
			onStartTime: undefined,
			onTick: undefined,
			onReady: undefined,
		}, options);

		$this = $(this);
		let timerId = null;
		//Разметка таймера
		function getTimerHtml() {
			return '<p class="h4">' + settings.text + ': <span class="time-text">00:00</span></p>';
		}
		//Инициализация
		function init() {
			$this.each(function () {
				$(this).append(getTimerHtml());
				$(this).data("state", "NotStarted");

				if (settings.onReady) {
					settings.onReady(this);
				}
			});

			return {
				this: this,
				api: api,
				init: init
			}
		}
		//Получить время
		function getTime(time) {
			if (!time) {
				return null;
			}
			var times = time.split(":");
			var ind = 0;
			var days = 0;
			var hours = 0;
			var tMin = 0;
			if (times.length > 1) {
				days = Math.floor(parseInt(times[0]) / 60 / 24);
				hours = Math.floor((parseInt(times[0]) - days * 24 * 60) / 60);

				tMin = parseInt(times[0]) - days * 24 * 60 - hours * 60;
			}
			var date = new Date(0, 0,
				days,
				hours,
				tMin,
				times[1]);
			return date;
		}
		//Выполнен таймаут
		function timerTick() {
			if ($this.data("state") === "Pause"
				|| $this.data("state") === "Ended"
				|| $this.data("state") === "Stop") {
				return;
			}
			clearTimeout($this.data("timer_id"));

			var endTime = getTime(settings.endTime);
			var startTime = getTime(settings.startTime);

			var t = getTime($(".time-text", $this).text());
			if (endTime.getTime() === t.getTime()) {
				$(this).data("state", "Ended");
				$(this).trigger("testTimer.end");
				if (settings.onEndedTime) {
					settings.onEndedTime(true);
				}
				return;
			}

			if (endTime === null || endTime > startTime) {
				api().setTime(0, 0, 1);
			} else if (endTime < startTime) {
				api().setTime(0, 0, -1);
			}
			$this.data("timer_id", setTimeout(timerTick, settings.tick));
		}
		//Формат вывода
		function formatNumberLength(num, length) {
			var r = "" + num;
			while (r.length < length) {
				r = "0" + r;
			}
			return r;
		}

		//API
		let api = function () {
			return {
				destroy: function () {
					$this.each(function () {
						$(this).html("");
						$(this).trigger("testTimer.destroyed");
					});
				},
				start: function () {
					$this.each(function () {
						if ($(this).data("state") === "NotStarted") {
							$(".time-text", $(this)).text(settings.startTime);
						}
						$(this).data("timer_id", setTimeout(timerTick, settings.tick));
						$(this).data("state", "Started");
						$(this).trigger("testTimer.start");
						if (settings.onStartTime) {
							settings.onStartTime();
						}
					});
				},
				stop: function () {
					$this.each(function () {
						if ($(this).data("state") === "Ended") {
							return;
						}
						$(this).data("state", "Stop");
						clearTimeout($(this).data("timer_id"));
						$(this).trigger("testTimer.end");
						if (settings.onEndedTime) {
							settings.onEndedTime(false);
						}
					});
				},
				pause: function () {
					$this.each(function () {
						$(this).data("state", "Pause");
						clearTimeout($(this).data("timer_id"));
					});
				},
				getTime: function () {
					return getTime($(".time-text", $this).text());
				},
				getTimeTotalSeconds: function () {
					var defTime = new Date(0, 0, 0, 0, 0, 0).getTime();
					var time = Math.abs(getTime($(".time-text", $this).text()).getTime() - defTime);
					return Math.round(time / 1000);
				},
				getTotalMinutes: function () {
					var defTime = new Date(0, 0, 0, 0, 0, 0).getTime();
					var time = Math.abs(getTime($(".time-text", $this).text()).getTime() - defTime);
					return Math.round(time / 1000 / 60);
				},
				getState: function () {
					return $this.data("state");
				},
				isTimeOff: function () {
					var time = getTime($(".time-text", $this).text());
					var defTime = new Date(0, 0, 0, 0, 0, 0).getTime();
					if (time.getTime() - defTime <= 0) {
						return true;
					}

					return false;
				},
				setTime: function (hours, minutes, seconds) {
					var time = getTime($(".time-text", $this).text());

					if (hours) {
						time.setHours(time.getHours() + hours);
					}
					if (minutes) {
						time.setMinutes(time.getMinutes() + minutes);
					}
					if (seconds) {
						time.setSeconds(time.getSeconds() + seconds);
					}


					//Дни в минуты
					var dM = time.getDay() * 24 * 60;
					//Переводим часы в минуты
					var hM = time.getHours() * 60;
					$(".time-text", $this).text(formatNumberLength(dM + hM + time.getMinutes(), 2) + ":" + formatNumberLength(time.getSeconds(), 2));
				},
				setTimeString: function (stringTime) {
					if (stringTime && stringTime != "") {
						var time = getTime(stringTime);
						var tims = stringTime.split(":");

						if (time && tims.length == 2) {
							$(".time-text", $this).text(formatNumberLength(parseInt(tims[0]), 2) + ":" + formatNumberLength(parseInt(tims[1]), 2));
						} else {
							$(".time-text", $this).text("00:00");
						}
					}
				},
				hide: function () {
					var p = $this.find("p");
					if (p.length != 0) {
						p.addClass("d-none");
					}
				},
				show: function () {
					var p = $this.find("p");
					if (p.length != 0) {
						p.removeClass("d-none");
					}
				}
			}
		}

		return {
			this: this,
			api: api,
			init: init
		}
	};
})(jQuery);