// CodeMirror, copyright (c) by Marijn Haverbeke and others
// Distributed under an MIT license: http://codemirror.net/LICENSE

(function(mod) {
  if (typeof exports == "object" && typeof module == "object") // CommonJS
    mod(require("../../lib/codemirror"));
  else if (typeof define == "function" && define.amd) // AMD
    define(["../../lib/codemirror"], mod);
  else // Plain browser env
    mod(CodeMirror);
})(function (CodeMirror) {
    "use strict";

    CodeMirror.defineMode("EScript", function () {
        function words(array) {
            var keys = {};
            for (var i = 0; i < array.length; ++i) {
                keys[array[i]] = true;
            }
            return keys;
        }

        var keywords = words(["GOTO", "IF", "PRINT", "PRINTH", "READ", "CASE"]);
        var builtins = words(["COS", "MAX", "MIN", "SIN", "SQRT", "TRUNC", "ROUND", "TAN", "ABS"]);
        var isOperatorChar = /[+\-*&=<>\/\:]/;

        function tokenBase(stream, state) {
            var ch = stream.next();
            if (ch == "/" && stream.eat("/")) {
                stream.skipToEnd();
                return "comment";
            }
            if (ch == '"' || ch == "'") {
                state.tokenize = tokenString(ch);
                return state.tokenize(stream, state);
            }
            if (/[\[\]\(\),]/.test(ch)) {
                return null;
            }
            if (/\d/.test(ch)) {
                stream.eatWhile(/[\w\.]/);
                return "number";
            }
            if (isOperatorChar.test(ch)) {
                stream.eatWhile(isOperatorChar);
                return "operator";
            }
            stream.eatWhile(/[\w\$_]/);
            var word = stream.current();

            if (keywords.hasOwnProperty(word)) {
                return 'keyword';
            }
            if (builtins.hasOwnProperty(word)) {
                return 'builtin';
            }
            return "variable";
        }

        function tokenString(quote) {
            return function (stream, state) {
                var escaped = false, next, end = false;
                while ((next = stream.next()) != null) {
                    if (next == quote && !escaped) {
                        end = true;
                        break;
                    }
                    escaped = !escaped && next == "\\";
                }
                if (end || !escaped) state.tokenize = null;
                return "string";
            };
        }

        // Interface
        return {
            startState: function () {
                return { tokenize: null };
            },
            token: function (stream, state) {
                if (stream.eatSpace()) return null;
                var style = (state.tokenize || tokenBase)(stream, state);
                if (style == "comment" || style == "meta") return style;
                return style;
            }
        };
    });

    CodeMirror.defineMIME("text/x-escript", "EScript");
});
