﻿var models = {
	selectelementid: null,
	linedata: [],
	coords: {
		client :[],
		svg :[],
		container :[],
		conpoint :[0, 0]
	}
};
 
var margin = { top: -5, right: -5, bottom: -5, left: -5 },
	width = $(window).width() * 2.5 - margin.left - margin.right,
	height = $(window).height() * 3 - margin.top - margin.bottom;

var zoom = d3.behavior.zoom()
	.scaleExtent([1, 10])
	.on("zoom", function () {
		container.attr("transform", "translate(" + d3.event.translate + ")scale(" + d3.event.scale + ")");
	});

var svg = d3.select("svg")
	.attr("width", width + margin.left + margin.right)
	.attr("height", height + margin.top + margin.bottom)
	.append("g")
	.attr("transform", "translate(" + margin.left + "," + margin.right + ")")
	.call(zoom);

var rect = svg.append("rect")
	.attr("width", width)
	.attr("height", height)
	.style("fill", "none")
	.style("pointer-events", "all");

var defs = svg.append('svg:defs');
for (var i = 0; i < arrvoltage.length; i++) {
	defs.append('svg:marker')
		.attr('id', "marker_path_end_" + arrvoltage[i])
		.attr('viewBox', '0 -5 10 10')
		.attr('refX', 0)
		.attr('markerWidth', 3)
		.attr('markerHeight', 3)
		.attr('orient', 'auto')
		.append('svg:path')
		.attr('d', 'M0, -5L10, 0L0, 5').style("stroke", function () {
			return "#" + arrvoltage[i];
		}).style("fill", function () {
			return "#" + arrvoltage[i];
		});
}

var container = svg.append("g").attr("id", "container");
container.append("g")
	.attr("class", "axis")
	.selectAll("line")
	.data(d3.range(0, width, 15))
	.enter().append("line")
	.attr("x1", function (d) { return d; })
	.attr("y1", 0)
	.attr("x2", function (d) { return d; })
	.attr("y2", height);
container.append("g")
	.attr("class", "axis")
	.selectAll("line")
	.data(d3.range(0, height, 15))
	.enter().append("line")
	.attr("x1", 0)
	.attr("y1", function (d) { return d; })
	.attr("x2", width)
	.attr("y2", function (d) { return d; });

var drag = d3.behavior.drag()
	.origin(function () {
		var transform = d3.transform(d3.select(this).attr("transform"));
		return { x: transform.translate[0], y: transform.translate[1] };
	})
	.on("dragstart", function () {
		d3.event.sourceEvent.stopPropagation();
		d3.select(this).classed("dragging", true);
	})
	.on("drag", function () {
		let obj = d3.select(this);
		obj.attr("transform", "translate(" + d3.event.x + "," + d3.event.y + ") rotate(" + d3.transform(obj.attr("transform")).rotate + ")");
	})
	.on("dragend", function () {
		d3.select(this).classed("dragging", false);
	});

var line = d3.svg.line()
	.x(function (d) { return d[0]; })
	.y(function (d) { return d[1]; })
	.interpolate('linear');

var redrawLine = function () {
	var lnk = container.selectAll('path.link')
		.data(models.linedata)
		.remove();
	lnk.enter().append('path')
		.attr('d', line(models.linedata))
		.attr('class', 'link');
	lnk.exit().remove();
};

svg.on("click", function () {
	var selectobjectid = $(".toolbox-img-select").attr("id");
	if (selectobjectid != "selectobject" && selectobjectid != "savescheme") {
		if ((selectobjectid == "line" || selectobjectid == "breakline") && models.linedata.length == 0) {
			if (Math.abs(models.coords.container[0] - models.coords.conpoint[0]) <= 6 &&
				Math.abs(models.coords.container[1] - models.coords.conpoint[1]) <= 6) {
				models.linedata[0] = [models.coords.conpoint[0], models.coords.conpoint[1]];

			} else {
				models.linedata[0] = [models.coords.container[0], models.coords.container[1]];
			}
			redrawLine();
		}
		else {
			let _elementid = we_helper.newGuid();
			switch (selectobjectid) {
				case "txt":
					{
						var txt = prompt("Введите текст", "");
						if (txt != null && txt != "") {
							$.addtext(container, _elementid, txt, models.coords.container, 0, drag, 1);
						}
						break;
					}
				case "connpoint":
					{
						$.addconnpoint(container, _elementid, "", models.coords.container, 0, [5, -10], drag, 1, "");
						break;
					}
				case "line":
					{
						if (models.linedata.length == 2) {
							if (Math.abs(models.coords.container[0] - models.coords.conpoint[0]) <= 6 &&
								Math.abs(models.coords.container[1] - models.coords.conpoint[1]) <= 6) {
								models.linedata[1] = [models.coords.conpoint[0], models.coords.conpoint[1]];
							} else {
								models.linedata[1] = [models.coords.container[0], models.coords.container[1]];
							}
							container.selectAll('path.link').data(models.linedata).remove();
							$.addline(container, _elementid, "", line(models.linedata), [0, 0], 0, null, drag, "off", "none", 1, "");
							models.linedata = [];
						}
						break;
					}
				case "breakline":
					{
						if (models.linedata.length == 2) {
							models.linedata[1] = [models.coords.container[0], models.coords.container[1]];
							svg.selectAll('path.link').data(models.linedata).remove();
							$.addbreakline(container, _elementid, "", line(models.linedata), [0, 0], 0, null, drag, "off", "none", 1, "");
							models.linedata = [];
						}
						break;
					}
				case "bus":
					{
						var txt = prompt("Укажите длину шины", "100");
						if (txt != null && txt != "") {
							var w = isNaN(parseInt(txt)) ? 100 : parseInt(txt);
							$.addbus(container, _elementid, "", w, models.coords.container, 0, [0, -10], drag, "off", 1, "");
						}
						break;
					}
				case "fuse":
					{
						$.addfuse(container, _elementid, "", models.coords.container, 0, [40, 0], drag, "on", 1, "");
						break;
					}
				case "switch":
					{
						$.addswitch(container, _elementid, "", models.coords.container, 0, [0, -10], drag, "on", "on", "", 1, "");
						break;
					}
				case "disconnector":
					{
						$.adddisconnector(container, _elementid, "", models.coords.container, 0, [0, -10], drag, "on", "", 1, "");
						break;
					}
				case "shortcircuit":
					{
						$.addshortcircuit(container, _elementid, "", models.coords.container, 0, [0, -10], drag, "on", "", 1, "");
						break;
					}
				case "separator":
					{
						$.addseparator(container, _elementid, "", models.coords.container, 0, [0, -10], drag, "on", "", 1, "");
						break;
					}
				case "circuitbreaker":
					{
						$.addcircuitbreaker(container, _elementid, "", models.coords.container, 0, [0, -25], drag, "on", "", 1, "");
						break;
					}
				case "cutout":
					{
						$.addcutout(container, _elementid, "", models.coords.container, 0, [0, -25], drag, "on", "", 1, "");
						break;
					}
				case "selector":
					{
						$.addselector(container, _elementid, "", models.coords.container, 0, [0, -25], drag, "on", "", 1, "");
						break;
					}
				case "testunit":
					{
						$.addtestunit(container, _elementid, "", models.coords.container, 0, [40, 0], drag, "in", 1, "");
						break;
					}
				case "switchplugin":
					{
						$.addswitchplugin(container, _elementid, "", models.coords.container, 0, [40, 0], drag, "on", "on", "1", "", 1, "");
						break;
					}
				case "surge":
					{
						$.addsurge(container, _elementid, "", models.coords.container, 0, [30, 0], drag, 1, "");
						break;
					}
				case "grounding":
					{
						$.addgrounding(container, _elementid, "", models.coords.container, 0, [30, 0], drag, 1, "");
						break;
					}
				case "twowindingautotransformer":
					{
						$.addtwowindingautotransformer(container, _elementid, "", models.coords.container, 0, [45, 0], drag, 1, "");
						break;
					}
				case "threewindingautotransformer":
					{
						$.addthreewindingautotransformer(container, _elementid, "", models.coords.container, 0, [45, 0], drag, 1, "");
						break;
					}
				case "twowindingtransformer":
					{
						$.addtwowindingtransformer(container, _elementid, "", models.coords.container, 0, [45, 10], drag, 1, "");
						break;
					}
				case "threewindingtransformer":
					{
						$.addthreewindingtransformer(container, _elementid, "", models.coords.container, 0, [50, 10], drag, 1, "");
						break;
					}
				case "generator":
					{
						$.addgenerator(container, _elementid, "", models.coords.container, 0, [40, 5], drag, 1, "");
						break;
					}
				case "blinker":
					{
						$.addblinker(container, _elementid, "", models.coords.container, 0, [0, -10], drag, "on", 1, "");
						break;
					}
				case "reactor":
					{
						$.addreactor(container, _elementid, "", models.coords.container, 0, [20, 0], drag, 1, "");
						break;
					}
				case "unittransformer":
					{
						$.addunittransformer(container, _elementid, "", models.coords.container, 0, [40, 5], drag, 1, "");
						break;
					}
				case "userimg":
					{
						$('.dialog_select_img').modal('show');
						break;
					}
				case "currenttransformer":
					{
						$.addcurrenttransformer(container, _elementid, "", models.coords.container, 0, [20, 0], drag, 1, "");
						break;
					}
			}
			setColor(_elementid);
		}
	}
});

$("#svg_simulator_scheme").on("mousemove", function (event) {
	models.coords.client = [event.clientX, event.clientY];
	var svgElement = document.getElementById('svg_simulator_scheme');
	var p = svgElement.createSVGPoint();
	p.x = event.clientX;
	p.y = event.clientY;

	p = CordsTransform(p, svgElement);
	models.coords.svg = [p.x, p.y];

	p.x = event.clientX;
	p.y = event.clientY;
	var svgContainer = document.getElementById('container');
	p = CordsTransform(p, svgContainer);
	models.coords.container = [p.x, p.y];


	if (models.linedata.length != 0) {
		models.linedata[1] = [models.coords.container[0], models.coords.container[1]];
		redrawLine();
	}
});

$(".toolbox-img").click(function () {
	$(".toolbox-img").removeClass("toolbox-img-select");
	$(this).addClass("toolbox-img-select");
});

$("#fileupload").change(function (event) {
	var input = event.target;
	if (input && input.files[0]) {
		if (input.files[0].size < 524288) {
			if ((/\.(png)$/i).test(input.files[0].name)) {
				var reader = new FileReader();
				reader.onload = function () {
					var img = new Image;
					img.onload = function () {
						if (img.width <= 256 && img.height <= 256) {
							$.addimg(container, we_helper.newGuid(), reader.result, img.width, img.height, models.coords.container, 0, drag, 1);
							$('.dialog_select_img').modal('hide');
						}
						else {
							$("#imgfilename").text("Разрешение изображения должно быть не более 256х256 пискелей").addClass("text-danger").removeClass("text-success");
						}
					};
					img.src = reader.result;
				};
				reader.onerror = function (event) {
					$("#imgfilename").text("Файл не может быть прочитан: " + event.target.error.code).addClass("text-danger").removeClass("text-success");
				};
				reader.readAsDataURL(input.files[0]);
			} else {
				$("#imgfilename").text("Выберите .png файл").addClass("text-danger").removeClass("text-success");
			}
		} else {
			$("#imgfilename").text("Размер файла не может превышать 512 Kб").addClass("text-danger").removeClass("text-success");
		}
	}
});

$("#downloadscheme").click(function () {
	we_helper.showLoader();
	let x = 0, y = 0;
	container.selectAll(".group").each(function () {
		var g = d3.select(this);
		var transform = d3.transform(g.attr("transform"));
		x = transform.translate[0] > x ? transform.translate[0] : x;
		y = transform.translate[1] > y ? transform.translate[1] : y;
	});

	x = x == 0 ? $(window).width() : x + 100;
	y = y == 0 ? $(window).height() : y + 50;

	saveSvgAsPng(document.getElementsByTagName("svg")[0], "schema.png", { scale: 2, backgroundColor: "#FFFFFF", height: y, width: x });
	we_helper.hideLoader();
});

$(".toolbox-color").click(function () {
	$(".toolbox-color").removeClass("toolbox-color-select");
	$(this).addClass("toolbox-color-select");
});

$("#savescheme").click(function () {
	var jsonObj = [];
	container.selectAll(".group").each(function () {
		var g = d3.select(this);
		var transform = d3.transform(g.attr("transform"));
		var item = {};
		item["id"] = g.attr("id");
		item["elementType"] = g.attr("type");

		let tmp = g.attr("name");
		if (tmp !== null && tmp !== "") {
			item["name"] = tmp;
		}

		if (transform.translate[0] !== 0) {
			item["translateX"] = transform.translate[0].toString().replace('.', ',');
		}
		if (transform.translate[1] !== 0) {
			item["translateY"] = transform.translate[1].toString().replace('.', ',');
		}
		if (transform.rotate != 0) {
			item["rotate"] = transform.rotate.toString().replace('.', ',');
		}

		tmp = g.attr("moveground");
		if (tmp !== null && tmp !== "") {
			item["moveground"] = tmp;
		}

		tmp = g.attr("install");
		if (tmp !== null && tmp !== "") {
			item["install"] = tmp;
		}

		tmp = g.attr("onoff");
		if (tmp !== null && tmp !== "") {
			item["onoff"] = tmp;
		}

		tmp = g.attr("opertok");
		if (tmp !== null && tmp !== "") {
			item["opertok"] = tmp;
		}

		tmp = g.attr("poster");
		if (tmp !== null && tmp !== "") {
			item["poster"] = tmp;
		}

		tmp = g.attr("state");
		if (tmp !== null && tmp !== "") {
			item["state"] = tmp;
		}

		tmp = g.attr("voltage");
		if (tmp !== null && tmp !== "" && tmp !== "rgb(0, 0, 0)") {
			item["voltage"] = tmp;
		}

		tmp = g.attr("parid");
		if (tmp !== null && tmp !== "") {
			item["parentId"] = tmp;
		}

		if (g.attr("type") == SchemaElementType.Line
			|| g.attr("type") == SchemaElementType.Breakline) {
			var g_line = g.select(".path");

			tmp = g_line.attr("d");
			if (tmp !== null && tmp !== "") {
				item["data"] = tmp;
			}
			tmp = g_line.style("stroke-dasharray");
			if (tmp !== null && tmp !== "") {
				item["dasharray"] = tmp;
			}
		}

		if (g.attr("type") == SchemaElementType.Text) {
			var g_txt = g.select(".txt");
			tmp = g_txt.text();
			if (tmp !== null && tmp !== "") {
				item["txt"] = tmp;
			}
		} else {
			if (g.attr("type") != SchemaElementType.Userimg && g.attr("type") != SchemaElementType.Movegrounding
				&& g.attr("type") != SchemaElementType.Movegrounding90) {
				var g_txt = g.select("text");
				var txtransform = d3.transform(g_txt.attr("transform"));
				if (txtransform.translate[0] !== 0) {
					item["txtTranslateX"] = txtransform.translate[0].toString().replace('.', ',');
				}
				if (txtransform.translate[1] !== 0) {
					item["txtTranslateY"] = txtransform.translate[1].toString().replace('.', ',');
				}
				if (g_txt.attr("display") == "none") {
					item["txt"] = "none";
				}
			}
		}

		if (g.attr("type") == SchemaElementType.Bus) {
			tmp = g.attr("width");
			if (tmp !== null && tmp !== "") {
				item["width"] = tmp;
			}
		}

		if (g.attr("type") == SchemaElementType.Userimg) {
			var img = g.select("image");
			item["width"] = img.attr("width");
			item["height"] = img.attr("height");
			item["data"] = img.attr("xlink:href");
		}

		jsonObj.push(item);
	});

 
	we_helper.updateDataDB("/Designer/UpdateSchema", {
		trainingid: page._trainingid,
		schemaData: jsonObj
	}, function () {
		jsonObj = [];
		we_helper.hideLoader();
	});
});

$(window).bind('beforeunload', function () {
	return 'Возможно внесенные изменения не сохранены.';
});
$(document).bind("mousedown", function (e) {
	if (!$(e.target).parents(".custom-menu").length > 0) {
		$(".custom-menu").hide(100);
	}
});
$('.dialog_select_img').on('hidden.bs.modal', function (e) {
	$("#imgfilename").text("").addClass("text-success").removeClass("text-danger");
	$("#fileupload").val("");
});

$(function () {
    page.init();
    $(window).resize(function () {
        page.resize();
	});
	document.oncontextmenu = function () { return false; };
});

var page = {
	_trainingid: we_helper.urlParam("trainingid"),
	init: function () {
		we_helper.setBreadcrumb([{ page: "Конструктор", path: "#" },
		{ page: "Задания типа «Тренировка»", path: "/designer?pageid=training" },
		{ page: "Редактор схем тренировки" }]);

		we_helper.getDataDB("/Designer/GetSchema", {
			trainingid: page._trainingid
		}, "query", false, function (schema) {
			$(".js_page_info").html("<strong>Тренировка:</strong> " + schema.num + ". " + schema.name).removeClass("d-none");
			if (schema.elems.length != 0) {
				$.each(schema.elems, function (key) {
					var translate = [schema.elems[key].translateX, schema.elems[key].translateY];
					var txtranslate = [schema.elems[key].txtTranslateX, schema.elems[key].txtTranslateY];
					var showname = schema.elems[key].txt != null ? schema.elems[key].txt : "";
					switch (schema.elems[key].elementType) {
						case SchemaElementType.Text:
							{
								$.addtext(container, schema.elems[key].id, schema.elems[key].txt, translate, schema.elems[key].rotate, drag, 1);
								break;
							}
						case SchemaElementType.Connpoint:
							{
								$.addconnpoint(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Blinker:
							{
								$.addblinker(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, 1, showname);
								break;
							}
						case SchemaElementType.Line:
							{
								$.addline(container, schema.elems[key].id, schema.elems[key].name, schema.elems[key].data, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].moveground, schema.elems[key].dasharray, 1, showname);
								break;
							}
						case SchemaElementType.Breakline:
							{
								$.addbreakline(container, schema.elems[key].id, schema.elems[key].name, schema.elems[key].data, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].moveground, schema.elems[key].dasharray, 1, showname);
								break;
							}
						case SchemaElementType.Bus:
							{
								$.addbus(container, schema.elems[key].id, schema.elems[key].name, schema.elems[key].width, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].moveground, 1, showname);
								break;
							}
						case SchemaElementType.Fuse:
							{
								$.addfuse(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].install, 1, showname);
								break;
							}
						case SchemaElementType.Switch:
							{
								$.addswitch(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].opertok, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Disconnector:
							{
								$.adddisconnector(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Shortcircuit:
							{
								$.addshortcircuit(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Separator:
							{
								$.addseparator(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Circuitbreaker:
							{
								$.addcircuitbreaker(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Cutout:
							{
								$.addcutout(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Selector:
							{
								$.addselector(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Testunit:
							{
								$.addtestunit(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, 1, showname);
								break;
							}
						case SchemaElementType.Switchplugin:
							{
								$.addswitchplugin(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, schema.elems[key].onoff, schema.elems[key].opertok, schema.elems[key].state, schema.elems[key].poster, 1, showname);
								break;
							}
						case SchemaElementType.Surge:
							{
								$.addsurge(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Grounding:
							{
								$.addgrounding(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Movegrounding90:
							{
								$.addmovegrounding90(d3.select("[id='" + schema.elems[key].parentId + "']"), schema.elems[key].id, translate);
								break;
							}
						case SchemaElementType.Movegrounding:
							{
								$.addmovegrounding(d3.select("[id='" + schema.elems[key].parentId + "']"), schema.elems[key].id, translate);
								break;
							}
						case SchemaElementType.Twowindingautotransformer:
							{
								$.addtwowindingautotransformer(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Threewindingautotransformer:
							{
								$.addthreewindingautotransformer(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Twowindingtransformer:
							{
								$.addtwowindingtransformer(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Threewindingtransformer:
							{
								$.addthreewindingtransformer(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Generator:
							{
								$.addgenerator(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Reactor:
							{
								$.addreactor(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Unittransformer:
							{
								$.addunittransformer(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						case SchemaElementType.Userimg:
							{
								$.addimg(container, schema.elems[key].id, schema.elems[key].data, schema.elems[key].width, schema.elems[key].height, translate, schema.elems[key].rotate, drag, 1);
								break;
							}
						case SchemaElementType.Currenttransformer:
							{
								$.addcurrenttransformer(container, schema.elems[key].id, schema.elems[key].name, translate, schema.elems[key].rotate, txtranslate, drag, 1, showname);
								break;
							}
						default:
							break;
					}

					if (schema.elems[key].elementType != SchemaElementType.Movegrounding90 && schema.elems[key].elementType != SchemaElementType.Movegrounding) {
						if (schema.elems[key].voltage == null) {
							schema.elems[key].voltage = "rgb(0, 0, 0)";
						}
						setColor(schema.elems[key].id, schema.elems[key].voltage);
					}
				});
			}
			we_helper.hideLoader();
		});
		page.resize();
	},
	resize: function () {
		$(".toolbox-container, .editor-container").height($(window).height() * 0.85);
	}
};
